import { feature } from 'topojson';
import { 
  select,
  csv,
  event,
  json,
  geoPath,
  geoMercator,
  geoNaturalEarth1,
	zoom
} from 'd3';

const svg = select('svg');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

g.append('path')
	.attr('d', pathGenerator({type: 'Sphere'}))
	.attr('class', 'land');


svg.call(zoom().on('zoom', () => {
  g.attr('transform', event.transform);
}));



Promise.all([
  csv('https://vizhub.com/arieltonglet/datasets/ne_10m_admin_0_countries.csv'),
  json('https://cdn.jsdelivr.net/npm/world-atlas@2/countries-110m.json')
]).then(([csvData, topoJsonData]) => {
  
  /*
  const countryName = {};
  csvData.forEach(d => {
    countryName[d.iso_n3] = d.name
  });
  */
  
  const countryName = csvData.reduce((accumulator, d) => {
    accumulator[d.iso_n3] = d.name;
    return accumulator;
  }, {});
  
  const countries = feature(topoJsonData, topoJsonData.objects.countries);
  	
  	g.selectAll('path').data(countries.features)
  		.enter().append('path')
  			.attr('d', pathGenerator)
  			.attr('class', 'country')
  		.append('title')
  			.text(d => countryName[d.id]);
  
});